<input id="{{ map_id }}" type="{{ widget.type }}" name="{{ widget.name }}"{% if widget.value != None %}
       value="{{ widget.value|stringformat:'s' }}"{% endif %}{% include "default_django/attrs.html" %}>
